@@ -1,4 +1,5 @@
 from ..himan.pandas.utils import load_file
+from pandas import DataFrame
 from pathlib import Path, PurePath
 
 
@@ -23,3 +24,8 @@ def test_should_accept_no_header_parameter():
     assert len(keys) == 2
     assert 'name' not in item.keys()
     assert item[0][1:] == ['John', 'Peter']
+
+def test_should_read_as_dataframe():
+    item = load_file(filepath, as_dataframe=True)
+
+    assert isinstance(item, DataFrame)
